NAME
IPC::Manager::Util - Utility functions for IPC::Manager
DESCRIPTION
This module provides utility functions used throughout the IPC::Manager distribution.
EXPORTS
The following functions are available via use IPC::Manager::Util qw(...):
- $bool = USE_INOTIFY()
-
Returns true if the Linux::Inotify2 module is available and supports the
fhmethod.This can be used as a constant.
- $bool = USE_IO_SELECT()
-
Returns true if the IO::Select module is available.
- $mod = require_mod($module)
-
Loads a module by name. Converts
::to/and appends.pm.Returns the original input.
- $val = pid_is_running($pid)
-
Checks if a PID is running.
returns 1 if the process is running and we have permissions.
returns 0 if the process does not exist.
return -1 if the process is running but we don't have permissions to do anything with it.
- $fh = clone_io($mode, $orig)
-
Clones a filehandle.
$modeis the open mode (e.g.'<','>','+<'), and$origis the filehandle to clone.Returns the filehandle clone.
SOURCE
The source code repository for IPC::Manager can be found at https://github.com/exodist/IPC-Manager.
MAINTAINERS
AUTHORS
COPYRIGHT
Copyright Chad Granum <exodist7@gmail.com>.
This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.